# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog][],
and this project adheres to [Semantic Versioning][].

[keep a changelog]: https://keepachangelog.com/en/1.0.0/
[semantic versioning]: https://semver.org/spec/v2.0.0.html

## [Unreleased]

## [v0.1.0]

### Added
- Basic tests for the base class, gpu and cpu-based methods {pr}`2`
- Added tests for evaluation and aggregatio modules {pr}`3`
- Added basic tutorial {pr}`3`
- Set up documentation on readthedocs {pr}`2`
- Set up precommit.ci
- Push the package to pypi
